@@ -1,9 +1,6 @@
 #!/usr/bin/perl
 
 # This is used as a diagnostic to send to the module author
-#
-#  perl dump.pl 2>&1 > dump.txt
-
 
 use strict;
 
@@ -17,3 +14,17 @@ my $copy = $fb;
 delete($copy->{'SCREEN'});
 
 print STDERR Dumper($copy);
+
+=head1 NAME
+
+Framebuffer Information Dump
+
+=head1 DESCRIPTION
+
+This script is used to help the author diagnose (and fix) any problems you may be having with the Graphics::Framebuffer module
+
+=head1 SYNOPSIS
+
+ perl dump.pl 2> gfb_dump.txt
+
+=cut
