@@ -1102,8 +1102,28 @@ sub mask_drawing {
     $F->blit_write($image1);
     $F->mask_mode();
     $F->blit_write($image2);
-    sleep $factor;
-
+    $image1 = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => $F->{'Y_CLIP'},
+            'width'  => $XX,
+            'height' => $h,
+            'file'   => "$images_path/GFB.png",
+            'center' => 3
+        }
+    );
+    $image2 = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => $F->{'Y_CLIP'},
+            'width'  => $XX,
+            'height' => $h,
+            'file'   => "$images_path/RWBY_beuowolf.jpg",
+            'center' => 3,
+            'convertalpha' => 1
+        }
+    );
+  
     if ($F->{'BITS'} > 16) {
         print_it($F,'Simulating MASK Mode with the much quicker "blit_transform" and "merge"');
         $F->blit_write($image1);
@@ -1112,7 +1132,7 @@ sub mask_drawing {
                 {
                     'blit_data' => $image2,
                     'merge'     => {
-                        'dest_blit_data'=> $F->blit_read($image2)
+                        'dest_blit_data'=> $image1
                     }
                 }
             )
@@ -1148,7 +1168,28 @@ sub unmask_drawing {
     $F->blit_write($image1);
     $F->unmask_mode();
     $F->blit_write($image2);
-    sleep $factor;
+    $image1 = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => $F->{'Y_CLIP'},
+            'width'  => $XX,
+            'height' => $h,
+            'file'   => "$images_path/RWBY_beuowolf.jpg",
+            'center' => 3,
+            'convertalpha' => 1
+        }
+    );
+    $image2 = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => $F->{'Y_CLIP'},
+            'width'  => $XX,
+            'height' => $h,
+            'file'   => "$images_path/RWBY_Alternate_Logo.png",
+            'center' => 3
+        }
+    );
+
     if ($F->{'BITS'} > 16) {
         print_it($F,'Simulating UNMASK Mode with the much quicker "blit_transform" and "merge"');
         $F->blit_write($image2);
@@ -1157,7 +1198,7 @@ sub unmask_drawing {
                 {
                     'blit_data' => $image1,
                     'merge'     => {
-                        'dest_blit_data'=> $F->blit_read($image1)
+                        'dest_blit_data'=> $image2
                     }
                 }
             )
