@@ -188,3 +188,41 @@ sub print_it {
     }
     $fb->normal_mode();
 } ## end sub print_it
+
+=head1 NAME
+
+Slide Show
+
+=head1 DESCRIPTION
+
+Multi-threaded, multi-framebuffer Slide Show
+
+This automatically detects all of the framebuffer devices in your system, and shows the images in the images path, in a random order, on all devices.
+
+=head1 SYNOPSIS
+
+ perl slideshow [file] [auto] [full] [errors] "path to images"
+
+=head2 OPTIONS
+
+=over 2
+
+=item C<auto>
+
+Turns on auto color level mode.  Sometimes this yields great results... and sometimes it totally ugly's things up
+
+=item C<errors>
+
+Allows the module to print errors to STDERR
+
+=item C<file>
+
+Makes the module render in file handle mode instead of memory mapped string mode.
+
+=item C<full>
+
+Scales all images (and animations) to full screen (proportionally).
+
+=back
+
+=cut
